@@ -1,4 +1,4 @@
-"f2f" <- function(f, pp=NA, xlo=NULL) {
+"f2f" <- function(f, pp=NA, xlo=NULL, type=c("ge", "gt")) {
    if(! check.fs(f)) return(FALSE)
    if(! is.null(xlo)) pp <- xlo$pp
    if(is.na(pp)) {
@@ -10,6 +10,11 @@
         return(FALSE)
       }
    }
-   f  <- f[f >= pp] # see identifical subsetting in f2flo
+   type <- match.arg(type)
+   if(type == "gt") {
+     f <- f[f >  pp] # see identifical subsetting in f2flo
+   } else {
+     f <- f[f >= pp] # see identifical subsetting in f2flo
+   }
    return(f)
-}
\ No newline at end of file
+}
