@@ -6,7 +6,7 @@ function(f, para, paracheck=TRUE, yacoubsintegral=TRUE, eps=1e-7) {
    }
 
    xmu <- lmomemu(para, nmom=1)$lambdas[1]
-  "quaemu.recur" <- function(f, para, x) {
+   "quaemu.recur" <- function(f, para, x) {
       if(x < 0) {
          x <- ifelse(abs(x) > xmu, xmu/2, abs(x)/2)
       }
@@ -19,22 +19,17 @@ function(f, para, paracheck=TRUE, yacoubsintegral=TRUE, eps=1e-7) {
         return(x) # stop recursion and return
       } else {
         fx <- pdfemu(x, para, paracheck=FALSE) # PDF of the lmomco package
+        fx[is.na(fx)] <- 0
         newx <- x + tmp/fx # as seen in the equation
         x.np1 <- quaemu.recur(f, para, newx)
         return(x.np1)
       }
    }
 
-   x <- vector(mode="numeric", length=length(f))
-   for(i in 1:length(f)) {
-     Fx <- f[i]
-     if(Fx == 0) {
-       x[i] <- 0
-     } else {
-       qua <- quaemu.recur(Fx, para, xmu)
-       x[i] <- qua
-     }
-   }
+   x <- quaemu.recur(f, para, xmu)
+
+   x[f == 0] <- 0
+   names(x) <- NULL
    return(x)
 }
 
